@@ -36,7 +36,7 @@ import adafruit_wiznet5k.adafruit_wiznet5k_dhcp as dhcp
 import adafruit_wiznet5k.adafruit_wiznet5k_dns as dns
 
 
-__version__ = "1.12.10"
+__version__ = "1.12.12"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Wiznet5k.git"
 
 
@@ -859,7 +859,7 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
             val_1 = self._read_snrx_rsr(sock)
             if val_1 != 0:
                 val = self._read_snrx_rsr(sock)
-        return int.from_bytes(val, "b")
+        return int.from_bytes(val, "big")
 
     def _get_tx_free_size(self, sock):
         """Get free size of sock's tx buffer block."""
@@ -869,7 +869,7 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
             val_1 = self._read_sntx_fsr(sock)
             if val_1 != 0:
                 val = self._read_sntx_fsr(sock)
-        return int.from_bytes(val, "b")
+        return int.from_bytes(val, "big")
 
     def _read_snrx_rd(self, sock):
         self._pbuff[0] = self._read_socket(sock, REG_SNRX_RD)[0]
